- data_dir
(character) Required directory path where the WCVP
data is saved
- occ
(data.frame or data.table) a data frame containing the occurrence
records to be flagged. Must contain columns for species, longitude, and
latitude.
- species
(character) the name of the column in occ that contains the
species scientific names. Default is "species".
- long
(character) the name of the column in occ that contains the
longitude values. Default is "decimalLongitude".
- lat
(character) the name of the column in occ that contains the
latitude values. Default is "decimalLatitude".
- origin
(character) vector specifying which origin categories should
be considered as part of the species' range. Options are: "native",
"introduced", "extinct", "location_doubtful", and "all". For example,
if origin = "introduced", only regions where the species is considered
introduced will be used to validate records. Default is "native".
- buffer
(numeric) buffer distance (in kilometers) to be applied
around the region of distribution. Default is 20 km.
- progress_bar
(logical) whether to display a progress bar during
processing. If TRUE, the 'pbapply' package must be installed. Default is
FALSE.
- verbose
(logical) if FALSE, prints messages about the progress and
the number of species being checked. Default is FALSE.