Learn R Programming

RuHere (version 1.0.1)

world: World Countries

Description

A "PackedSpatVector" containing country polygons from Natural Earth, processed and cleaned for use within the package. Country names were converted to lowercase and had accents removed.

Usage

world

Arguments

Format

A PackedSpatVector object with country polygons and one attribute:

name

Country name.

Details

The dataset is sourced from rnaturalearthdata::map_units110, then:

  • converted to a SpatVector using terra,

  • attribute "name" cleaned (tolower(), remove_accent()),

  • wrapped using terra::wrap() for robust internal storage.

Examples

Run this code
data(world)
world <- terra::unwrap(world)
terra::plot(world)

Run the code above in your browser using DataLab