powered by
A PackedSpatRaster containing three bioclimatic variables from the WorldClim, cropped to a region of interest South America.
PackedSpatRaster
worldclim
A SpatRaster with 3 layers and the following characteristics:
SpatRaster
151 rows × 183 columns
0.08333333° × 0.08333333°
xmin = -57.08333, xmax = -41.83333, ymin = -32.08333, ymax = -19.5
WGS84 (EPSG:4326)
Mean Annual Temperature (°C × 10)
Temperature Annual Range (°C × 10)
Annual Precipitation (mm)
This raster corresponds to three standard bioclimatic variables from the WorldClim 2.1 dataset.
data(worldclim) bioclim <- terra::unwrap(worldclim) terra::plot(bioclim)
Run the code above in your browser using DataLab