Identifies the data sources present in the output of get_datapaper()
and prints the appropriate bibliographic citations for use in academic and
technical publications.
Arguments
- data
A
data.frameordata.tableobtained fromget_datapaper(), containing thedata_sourcecolumn.
Value
Prints the formatted references to the console and invisibly returns a named character vector with the citations for the detected data sources.
Examples
if (FALSE) { # \dontrun{
# 1. Download data
dados <- get_datapaper(datapaper = "dryflor")
# 2. View citations
cite_datapaper(dados)
} # }