# Load data example
# Occurrences of Puma concolor from the atlanticr R package
data("puma_atlanticr", package = "RuHere")
# Create metadata to standardize the occurrences
puma_metadata <- create_metadata(occ = puma_atlanticr,
scientificName = "actual_species_name",
decimalLongitude = "longitude",
decimalLatitude = "latitude",
elevation = "altitude",
country = "country",
stateProvince = "state",
municipality = "municipality",
locality = "study_location",
year = "year_finish",
habitat = "vegetation_type",
datasetName = "reference")
# Now, we can use this metadata to standardize the columns
puma_occ <- format_columns(occ = puma_atlanticr, metadata = puma_metadata,
binomial_from = "actual_species_name",
data_source = "atlanticr")
Run the code above in your browser using DataLab