- data_dir
(character) a directory to save the data downloaded from
Fauna do Brazil.
- data_version
(character) version of the Fauna do Brazil database to
download. Use "latest" to get the most recent version, which is updated
frequently. Alternatively, specify an older version (e.g.,
data_version="1.2"). Default value is "latest".
- solve_discrepancy
(logical) whether to resolve inconsistencies
between species and subspecies information. When set to TRUE (default),
species information is updated based on unique data from subspecies. For
example, if a subspecies occurs in a certain state, it implies that the
species also occurs in that state.
- overwrite
(logical) If TRUE, data is overwritten. Default is TRUE.
- remove_files
(logical) whether to remove the downloaded files used in
building the final dataset. Default is TRUE.
- verbose
(logical) whether to display messages during function
execution. Set to TRUE to enable display, or FALSE to run silently. Default
is TRUE.