Learn R Programming

RuHere (version 1.0.1)

flag_colors: Color palette for flagged records

Description

flag_colors is a named character vector defining the default colors used to plot occurrence records flagged with mapview_here().

Usage

flag_colors

Arguments

Format

A named character vector where:

names

Flag labels corresponding to categories generated by the various flag_* and checking functions.

values

Hex color codes or standard R color names used for plotting.

See Also

mapview_here

Examples

Run this code
data(flag_colors)

# View all flag categories and their colors
flag_colors

Run the code above in your browser using DataLab