powered by
flag_colors is a named character vector defining the default colors used to plot occurrence records flagged with mapview_here().
flag_colors
mapview_here()
A named character vector where:
Flag labels corresponding to categories generated by the various flag_* and checking functions.
flag_*
Hex color codes or standard R color names used for plotting.
mapview_here
data(flag_colors) # View all flag categories and their colors flag_colors
Run the code above in your browser using DataLab