A data.frame that is the original occ data frame augmented with
a new column named fossil_flag. Records identified as fossils receive
FALSE, while all other records receive TRUE.
Arguments
occ
(data.frame) a data frame containing the occurrence records to be
examined, preferably standardized using format_columns(). Must contain the
columns specified in columns.
columns
(character) vector of column names in occ where the function
will search for the term "fossil" or other fossil-related expressions.
Default is c("basisOfRecord", "occurrenceRemarks").
fossil_terms
(character) optional vector of additional terms that
indicate a fossil record (e.g., "paleontological", "subfossil"). Default
is NULL.