- data_dir
(character) a directory to save the data downloaded from
Flora e Funga do Brasil.
- data_version
(character) version of the Flora e Funga do Brasil
database to download. Use "latest" to get the most recent version, updated
weekly. Alternatively, specify an older version (e.g.,
data_version="393.319"). Default value is "latest".
- solve_discrepancy
(logical) whether to resolve discrepancies between
species and subspecies/varieties information. When set to TRUE, species
information is updated based on unique data from varieties and subspecies.
For example, if a subspecies occurs in a certain biome, it implies that the
species also occurs in that biome. Default is TRUE.
- overwrite
(logical) if TRUE, data is overwritten. Default = TRUE.
- remove_files
(logical) whether to remove the downloaded files used in
building the final dataset. Default is TRUE.
- verbose
(logical) whether to display messages during function
execution. Set to TRUE to enable display, or FALSE to run silently. Default
is TRUE.