Learn R Programming

RuHere (version 1.0.1)

occ_bien: Occurrence records of Yellow Trumpet Tree from BIEN

Description

A cleaned dataset of occurrence records for Yellow Trumpet Tree (Handroanthus serratifolius) retrieved from the BIEN database. The raw data were downloaded using get_bien()

The dataset was subsequently processed with the package’s internal flagging workflow (flag_duplicates() and remove_flagged()) to remove duplicated records.

Usage

occ_bien

Arguments

Format

A data frame containing spatial coordinates, taxonomic information, and metadata returned by BIEN, after cleaning. Columns include (but may not be limited to):

  • scrubbed_species_binomial: Cleaned species name

  • longitude, latitude: Geographic coordinates

  • country, state_province, and other political boundary fields

See Also

get_bien()

Examples

Run this code
# View dataset
head(occ_bien)

# Number of records
nrow(occ_bien)


Run the code above in your browser using DataLab