Learn R Programming

RuHere (version 1.0.1)

occ_flagged: Flagged occurrence records of Araucaria angustifolia

Description

A dataset containing the occurrence records of Araucaria angustifolia after applying several of the package’s flagging and data-quality assessment functions.

Usage

occ_flagged

Arguments

Format

A data frame where each row corresponds to a georeferenced occurrence of A. angustifolia.

See Also

occurrences, standardize_countries(), standardize_states(), flag_florabr(), flag_wcvp(), flag_iucn(), flag_cultivated(), flag_inaturalist(), flag_duplicates(), mapview_here()

Examples

Run this code
# First rows
head(occ_flagged)

# Count flagged vs. unflagged records
table(occ_flagged$correct_country)


Run the code above in your browser using DataLab