Learn R Programming

RuHere (version 1.0.1)

occ_gbif: Occurrence records of Araucaria angustifolia from GBIF

Description

A cleaned dataset of occurrence records for Araucaria angustifolia (Parana pine) retrieved from GBIF.

Records were downloaded using the package’s GBIF workflow (prepare_gbif_download(), request_gbif(), import_gbif()), and then cleaned using the internal flagging workflow (duplicate detection and removal).

Usage

occ_gbif

Arguments

Format

A data frame containing georeferenced GBIF occurrence records for A. angustifolia after all cleaning steps.

See Also

prepare_gbif_download(), request_gbif(), import_gbif(), flag_duplicates(), remove_flagged()

Examples

Run this code
# Preview dataset
head(occ_gbif)

# Number of cleaned records
nrow(occ_gbif)

Run the code above in your browser using DataLab