Prepare data to request GBIF download
prepare_gbif_download(
species,
rank = NULL,
kingdom = NULL,
phylum = NULL,
class = NULL,
order = NULL,
family = NULL,
genus = NULL,
strict = FALSE,
progress_bar = FALSE,
...
)A data.frame with species information, including the number of occurrences and other related details.
(character) a vector of species name(s).
(character) optional taxonomic rank (for example, 'species' or 'genus'). Default is NULL, meaning it will return species matched across all ranks.
(character) optional taxonomic kingdom (for example, 'Plantae' or 'Animalia'). Default is NULL, meaning it will return species matched across all kingdoms.
(character) optional taxonomic phylum. Default is NULL, meaning it will return species matched across all phyla.
(character) optional taxonomic class. Defaults is NULL, meaning it will return species matched across all classes.
(character) optional taxonomic order. Defaults is NULL, meaning it will return species matched across all orders
(character) optional taxonomic family. Defaults is NULL, meaning it will return species matched across all families.
(character) optional taxonomic genus. Defaults is NULL, meaning it will return species matched across all genus.
(logical) If TRUE, it (fuzzy) matches only the given name, but never a taxon in the upper classification. Default is FALSE.
(logical) whether to display a progress bar during
processing. If TRUE, the 'pbapply' package must be installed. Default is
FALSE.
other parameters passed to rgbif::occ_count().
# \donttest{
gbif_prepared <- prepare_gbif_download(species = "Araucaria angustifolia")
# }
Run the code above in your browser using DataLab