- gbif_info
an object of class 'gbif_info' resulted by the
prepare_gbif_download() function.
- hasCoordinate
(logical) whether to retrieve only records with coordinates. Default is TRUE.
- hasGeospatialIssue
(logical) whether to retrieve records identified with geospatial issue. Default is FALSE.
- format
(character) the download format. Options available are 'DWCA',
'SIMPLE_CSV', or 'SPECIES_LIST', Default is DWCA'.
- gbif_user
(character) user name within GBIF's website. Default is
NULL, meaning it will try to obtain this information from the R enviroment.
(check set_gbif_credentials()) for more details.
- gbif_pwd
(character) user password within GBIF's website. Default is
NULL, meaning it will try to obtain this information from the R enviroment.
- gbif_email
(character) user email within GBIF's website. Default is
NULL, meaning it will try to obtain this information from the R enviroment.
- additional_predicates
(character or occ_predicate) additional
supported predicates that can be combined to build more complex download requests. See
rgbif::pred() for details.