wcvp_here: Download distribution data from the World Checklist of Vascular Plants (WCVP)
Description
This function downloads the World Checklist of Vascular Plants database,
which is required for filtering occurrence records using specialists'
information via the flag_wcvp() function.
# \donttest{# Define a directory to save the datadata_dir <- tempdir() # Here, a temporary directory# Download the WCVP databasewcvp_here(data_dir = data_dir)
# }